#ifndef EFL_UI_POPUP_IMPL_HH
#define EFL_UI_POPUP_IMPL_HH

#include "efl_ui_popup.eo.hh"

namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<Efl_Ui_Popup_Align>::type Popup::align_get() const
{
   Efl_Ui_Popup_Align __return_value =  ::efl_ui_popup_align_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Popup_Align>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Popup::align_set( ::efl::eolian::in_traits<Efl_Ui_Popup_Align>::type type) const
{
    ::efl_ui_popup_align_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Popup_Align,  ::efl::eolian::in_traits<Efl_Ui_Popup_Align>::type>(type));
}
inline ::efl::eolian::return_traits<double>::type Popup::timeout_get() const
{
   double __return_value =  ::efl_ui_popup_timeout_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Popup::timeout_set( ::efl::eolian::in_traits<double>::type time) const
{
    ::efl_ui_popup_timeout_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(time));
}
inline ::efl::eolian::return_traits<Eina_Size2D>::type Popup::popup_size_get() const
{
   Eina_Size2D __return_value =  ::efl_ui_popup_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Size2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Popup::popup_size_set( ::efl::eolian::in_traits<Eina_Size2D>::type size) const
{
    ::efl_ui_popup_size_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Size2D,  ::efl::eolian::in_traits<Eina_Size2D>::type>(size));
}
#ifdef EFL_CXXPERIMENTAL
::efl::eolian::return_traits<::efl::ui::Popup_Part>::type Popup::backwall() const
{
   ::Eo *__return_value = ::efl_part_get(this->_eo_ptr(), "backwall");
   return ::efl::ui::Popup_Part{__return_value};
}
#endif
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<Efl_Ui_Popup_Align>::type Popup::align_get() const
{
   Efl_Ui_Popup_Align __return_value =  ::efl_ui_popup_align_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Popup_Align>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Popup::align_set( ::efl::eolian::in_traits<Efl_Ui_Popup_Align>::type type) const
{
    ::efl_ui_popup_align_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Popup_Align,  ::efl::eolian::in_traits<Efl_Ui_Popup_Align>::type>(type));
}
inline ::efl::eolian::return_traits<double>::type Popup::timeout_get() const
{
   double __return_value =  ::efl_ui_popup_timeout_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Popup::timeout_set( ::efl::eolian::in_traits<double>::type time) const
{
    ::efl_ui_popup_timeout_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(time));
}
inline ::efl::eolian::return_traits<Eina_Size2D>::type Popup::popup_size_get() const
{
   Eina_Size2D __return_value =  ::efl_ui_popup_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Size2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Popup::popup_size_set( ::efl::eolian::in_traits<Eina_Size2D>::type size) const
{
    ::efl_ui_popup_size_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Size2D,  ::efl::eolian::in_traits<Eina_Size2D>::type>(size));
}
#ifdef EFL_CXXPERIMENTAL
::efl::eolian::return_traits<::efl::ui::Popup_Part>::type Popup::backwall() const
{
   ::Eo *__return_value = ::efl_part_get(this->_eo_ptr(), "backwall");
   return ::efl::ui::Popup_Part{__return_value};
}
#endif
inline efl::ui::Popup::operator ::efl::ui::Popup() const { return *static_cast< ::efl::ui::Popup const*>(static_cast<void const*>(this)); }
inline efl::ui::Popup::operator ::efl::ui::Popup&() { return *static_cast< ::efl::ui::Popup*>(static_cast<void*>(this)); }
inline efl::ui::Popup::operator ::efl::ui::Popup const&() const { return *static_cast< ::efl::ui::Popup const*>(static_cast<void const*>(this)); }
} } }
#endif
